@@ -245,7 +245,6 @@ class OrcaPrefs:
         prefs.writelines( \
                  "# be overwritten, edit %s-customizations.py.\n" % appName)
         prefs.writelines("#\n")
-        prefs.writelines("import importlib\n")
         prefs.writelines("import orca.settings\n")
         prefs.writelines("import orca.acss\n")
         prefs.writelines("\n")
@@ -261,7 +260,7 @@ class OrcaPrefs:
 
         prefs.writelines("\ntry:\n")
         prefs.writelines( \
-           "    importlib.import_module(\"app-settings.%s-customizations\")\n" % appName)
+           "    __import__(\"app-settings.%s-customizations\")\n" % appName)
         prefs.writelines("except ImportError:\n")
         prefs.writelines("    pass\n")
 
@@ -276,7 +275,7 @@ class OrcaPrefs:
 
         if not factory:
             return None
-        elif isinstance(factory, basestring):
+        elif isinstance(factory, str):
             return "'%s'" % factory
         else:
             return "'%s'" % factory.__name__
