@@ -210,50 +210,6 @@ class Utilities(script_utilities.Utilities):
 
         return parent
 
-    def findPreviousObject(self, obj):
-        """Finds the object before this one."""
-
-        if not obj:
-            return None
-
-        for relation in obj.getRelationSet():
-            if relation.getRelationType() == pyatspi.RELATION_FLOWS_FROM:
-                return relation.getTarget(0)
-
-        index = obj.getIndexInParent() - 1
-        if not (0 <= index < obj.parent.childCount - 1):
-            obj = obj.parent
-            index = obj.getIndexInParent() - 1
-
-        try:
-            prevObj = obj.parent[index]
-        except:
-            prevObj = obj
-
-        return prevObj
-
-    def findNextObject(self, obj):
-        """Finds the object after this one."""
-
-        if not obj:
-            return None
-
-        for relation in obj.getRelationSet():
-            if relation.getRelationType() == pyatspi.RELATION_FLOWS_TO:
-                return relation.getTarget(0)
-
-        index = obj.getIndexInParent() + 1
-        if not (0 < index < obj.parent.childCount):
-            obj = obj.parent
-            index = obj.getIndexInParent() + 1
-
-        try:
-            nextObj = obj.parent[index]
-        except:
-            nextObj = None
-
-        return nextObj
-
     #########################################################################
     #                                                                       #
     # Impress-Specific Utilities                                            #
@@ -400,7 +356,7 @@ class Utilities(script_utilities.Utilities):
         - endOffset: the ending character position
         """
 
-        text = obj.queryText().getText(0, -1).decode("UTF-8")
+        text = obj.queryText().getText(0, -1)
         if startOffset >= len(text):
             startOffset = len(text) - 1
         if endOffset == -1:
@@ -408,7 +364,6 @@ class Utilities(script_utilities.Utilities):
         elif startOffset >= endOffset:
             endOffset = startOffset + 1
         string = text[max(0, startOffset):min(len(text), endOffset)]
-        string = string.encode("UTF-8")
 
         return string
 
