@@ -306,6 +306,22 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                     self, obj, **args))
         return result
 
+    def _generateFocusedItem(self, obj, **args):
+        result = []
+        role = args.get('role', obj.getRole())
+        if role != pyatspi.ROLE_LIST:
+            return result
+
+        s = obj.querySelection()
+        items = [s.getSelectedChild(i) for i in range(s.nSelectedChildren)]
+        if not items and obj.childCount:
+            items.append(obj[0])
+        items = list(map(self._generateName, items))
+        for item in items:
+            result.extend(item)
+
+        return result
+
     def _generateAncestors(self, obj, **args):
         result = []
         priorObj = args.get('priorObj', None)
@@ -380,7 +396,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             #
             parentText = self._script.utilities.queryNonEmptyText(parent)
             if parentText:
-                unicodeText = parentText.getText(0, -1).decode("UTF-8")
+                unicodeText = parentText.getText(0, -1)
                 if self._script.EMBEDDED_OBJECT_CHARACTER in unicodeText \
                    and (len(unicodeText) == 1 \
                         or role == pyatspi.ROLE_TABLE_CELL):
