@@ -108,36 +108,6 @@ class Script(default.Script):
                 #
                 _("Speaks entire document."))
 
-        self.inputEventHandlers["panBrailleLeftHandler"] = \
-            input_event.InputEventHandler(
-                Script.panBrailleLeft,
-                # Translators: a refreshable braille display is an
-                # external hardware device that presents braille
-                # character to the user.  There are a limited number
-                # of cells on the display (typically 40 cells).  Orca
-                # provides the feature to build up a longer logical
-                # line and allow the user to press buttons on the
-                # braille display so they can pan left and right over
-                # this line.
-                #
-                _("Pans the braille display to the left."),
-                False) # Do not enable learn mode for this action
-
-        self.inputEventHandlers["panBrailleRightHandler"] = \
-            input_event.InputEventHandler(
-                Script.panBrailleRight,
-                # Translators: a refreshable braille display is an
-                # external hardware device that presents braille
-                # character to the user.  There are a limited number
-                # of cells on the display (typically 40 cells).  Orca
-                # provides the feature to build up a longer logical
-                # line and allow the user to press buttons on the
-                # braille display so they can pan left and right over
-                # this line.
-                #
-                _("Pans the braille display to the right."),
-                False) # Do not enable learn mode for this action
-
     def getToolkitKeyBindings(self):
         """Returns the toolkit-specific keybindings for this script."""
 
@@ -427,7 +397,7 @@ class Script(default.Script):
 
         phrase = self.utilities.substring(obj, startOffset, endOffset)
         if len(phrase) and phrase != "\n":
-            if phrase.decode("UTF-8").isupper():
+            if phrase.isupper():
                 voice = self.voices[settings.UPPERCASE_VOICE]
             else:
                 voice = self.voices[settings.DEFAULT_VOICE]
@@ -478,12 +448,9 @@ class Script(default.Script):
         if not self.utilities.isWebKitGtk(orca_state.locusOfFocus):
             return False
 
-        states = orca_state.locusOfFocus.getState()
-        if states.contains(pyatspi.STATE_EDITABLE):
-            return False
-
         role = orca_state.locusOfFocus.getRole()
         if role in doNotHandleRoles:
+            states = orca_state.locusOfFocus.getState()
             if role == pyatspi.ROLE_LIST_ITEM:
                 return not states.contains(pyatspi.STATE_SELECTABLE)
 
@@ -523,52 +490,6 @@ class Script(default.Script):
 
         return child, index
 
-    def panBrailleLeft(self, inputEvent=None, panAmount=0):
-        """In document content, we want to use the panning keys to browse the
-        entire document.
-        """
-
-        if self.flatReviewContext \
-           or not self.isBrailleBeginningShowing() \
-           or not self.utilities.isWebKitGtk(orca_state.locusOfFocus):
-            return default.Script.panBrailleLeft(self, inputEvent, panAmount)
-
-        obj = self.utilities.findPreviousObject(orca_state.locusOfFocus)
-        orca.setLocusOfFocus(None, obj, notifyScript=False)
-        self.updateBraille(obj)
-
-        # Hack: When panning to the left in a document, we want to start at
-        # the right/bottom of each new object. For now, we'll pan there.
-        # When time permits, we'll give our braille code some smarts.
-        while self.panBrailleInDirection(panToLeft=False):
-            pass
-        self.refreshBraille(False)
-
-        return True
-
-    def panBrailleRight(self, inputEvent=None, panAmount=0):
-        """In document content, we want to use the panning keys to browse the
-        entire document.
-        """
-
-        if self.flatReviewContext \
-           or not self.isBrailleEndShowing() \
-           or not self.utilities.isWebKitGtk(orca_state.locusOfFocus):
-            return default.Script.panBrailleRight(self, inputEvent, panAmount)
-
-        obj = self.utilities.findNextObject(orca_state.locusOfFocus)
-        orca.setLocusOfFocus(None, obj, notifyScript=False)
-        self.updateBraille(obj)
-
-        # Hack: When panning to the right in a document, we want to start at
-        # the left/top of each new object. For now, we'll pan there. When time
-        # permits, we'll give our braille code some smarts.
-        while self.panBrailleInDirection(panToLeft=True):
-            pass
-        self.refreshBraille(False)
-
-        return True
-
     def sayAll(self, inputEvent):
         """Speaks the contents of the document beginning with the present
         location.  Overridden in this script because the sayAll could have
@@ -610,17 +531,8 @@ class Script(default.Script):
         spoken and acss is an ACSS instance for speaking the text.
         """
 
-        if not obj:
-            return
-
-        if obj.getRole() == pyatspi.ROLE_LINK:
-            obj = obj.parent
-
         document = utils.findAncestor(
             obj, lambda x: x.getRole() == pyatspi.ROLE_DOCUMENT_FRAME)
-        if not document:
-            return
-
         allTextObjs = utils.findAllDescendants(
             document, lambda x: 'Text' in utils.listInterfaces(x))
         allTextObjs = allTextObjs[allTextObjs.index(obj):len(allTextObjs)]
@@ -690,53 +602,13 @@ class Script(default.Script):
         where the caret is.
         """
 
+        # TODO - JD: Piece together the full line for braille
+
         textLine = default.Script.getTextLineAtCaret(self, obj, offset)
-        string = textLine[0].decode('UTF-8')
-        if string and string.find(self.EMBEDDED_OBJECT_CHARACTER) == -1 \
-           and obj.getState().contains(pyatspi.STATE_FOCUSED):
+        string = textLine[0]
+        if string.find(self.EMBEDDED_OBJECT_CHARACTER) == -1:
             return textLine
 
         textLine[0] = self.utilities.displayedText(obj)
-        try:
-            text = obj.queryText()
-        except:
-            pass
-        else:
-            textLine[1] = min(textLine[1], text.characterCount)
 
         return textLine
-
-    def updateBraille(self, obj, extraRegion=None):
-        """Updates the braille display to show the given object.
-
-        Arguments:
-        - obj: the Accessible
-        - extra: extra Region to add to the end
-        """
-
-        if not obj:
-            return
-
-        if not self.utilities.isWebKitGtk(obj) \
-           or (not self.utilities.isInlineContainer(obj) \
-               and not self.utilities.isTextListItem(obj)):
-            default.Script.updateBraille(self, obj, extraRegion)
-            return
-
-        brailleLine = self.getNewBrailleLine(clearBraille=True, addLine=True)
-        for child in obj:
-            if not self.utilities.onSameLine(child, obj[0]):
-                break
-            [regions, fRegion] = self.brailleGenerator.generateBraille(child)
-            self.addBrailleRegionsToLine(regions, brailleLine)
-
-        if not brailleLine.regions:
-            [regions, fRegion] = self.brailleGenerator.generateBraille(
-                obj, role=pyatspi.ROLE_PARAGRAPH)
-            self.addBrailleRegionsToLine(regions, brailleLine)
-            self.setBrailleFocus(fRegion)
-
-        if extraRegion:
-            self.addBrailleRegionToLine(extraRegion, brailleLine)
-
-        self.refreshBraille()
