@@ -102,10 +102,6 @@ class Utilities(script_utilities.Utilities):
         """
 
         text = script_utilities.Utilities.displayedText(self, obj)
-        try:
-            text = text.decode('UTF-8')
-        except:
-            pass
         if text and text != self.EMBEDDED_OBJECT_CHARACTER:
             return text
 
@@ -134,7 +130,7 @@ class Utilities(script_utilities.Utilities):
         except (AttributeError, NotImplementedError):
             return [(obj, 0, 1, '')]
 
-        string = text.getText(0, -1).decode('UTF-8')
+        string = text.getText(0, -1)
         if not string:
             return [(obj, 0, 1, '')]
 
@@ -168,84 +164,3 @@ class Utilities(script_utilities.Utilities):
         objects = [x for x in objects if x[1] < x[2]]
 
         return objects
-
-    def findPreviousObject(self, obj):
-        """Finds the object before this one."""
-
-        if not obj:
-            return None
-
-        if obj.getRole() == pyatspi.ROLE_LINK:
-            obj = obj.parent
-
-        index = obj.getIndexInParent() - 1
-        if not (0 <= index < obj.parent.childCount - 1):
-            obj = obj.parent
-            index = obj.getIndexInParent() - 1
-
-        try:
-            prevObj = obj.parent[index]
-        except:
-            prevObj = obj
-        else:
-            if prevObj.getRole() == pyatspi.ROLE_LIST and prevObj.childCount:
-                if self.isTextListItem(prevObj[0]):
-                    prevObj = prevObj[-1]
-
-        return prevObj
-
-    def findNextObject(self, obj):
-        """Finds the object after this one."""
-
-        if not obj:
-            return None
-
-        if obj.getRole() == pyatspi.ROLE_LINK:
-            obj = obj.parent
-
-        index = obj.getIndexInParent() + 1
-        if not (0 < index < obj.parent.childCount):
-            obj = obj.parent
-            index = obj.getIndexInParent() + 1
-
-        try:
-            nextObj = obj.parent[index]
-        except:
-            nextObj = None
-        else:
-            if nextObj.getRole() == pyatspi.ROLE_LIST and nextObj.childCount:
-                if self.isTextListItem(nextObj[0]):
-                    nextObj = nextObj[0]
-
-        return nextObj
-
-    def isTextListItem(self, obj):
-        """Returns True if obj is an item in a non-selectable list."""
-
-        if obj.getRole() != pyatspi.ROLE_LIST_ITEM:
-            return False
-
-        return not obj.parent.getState().contains(pyatspi.STATE_FOCUSABLE)
-
-    def isInlineContainer(self, obj):
-        """Returns True if obj is an inline/non-wrapped container."""
-
-        if obj.getRole() == pyatspi.ROLE_SECTION:
-            if obj.childCount > 1:
-                return self.onSameLine(obj[1], obj[1])
-
-            return False
-
-        if obj.getRole() == pyatspi.ROLE_LIST:
-            if obj.getState().contains(pyatspi.STATE_FOCUSABLE):
-                return False
-
-            if not obj.childCount:
-                return 'Text' in pyatspi.utils.listInterfaces(obj)
-
-            if obj.childCount == 1:
-                return False
-
-            return self.onSameLine(obj[0], obj[1])
-
-        return False
